This crate contains kube-rs compatible bindings for Kubernetes custom resources for the eks.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
eks.services.k8s.aws/v1alpha1
AddonClusterFargateProfileNodegroup